@@ -1,6 +1,7 @@
 setClass("SpatialPointsDataFrame",
 	representation("SpatialPoints", data = "AttributeList", coords.nrs = "numeric"),
-	prototype = list(new("SpatialPoints"), data = new("AttributeList", att=list()), 
+	prototype = list(bbox = matrix(NA), proj4string = CRS(as.character("NA")),
+		coords = matrix(NA), data = new("AttributeList", att=list()), 
 		coords.nrs = numeric(0)),
 	validity = function(object) {
 		#if (!inherits(object@data, "data.frame"))
