@@ -16,22 +16,24 @@ pointsInPolygon = function(pts, Polygon) {
 
 pointsInPolygons = function(pts, Polygons, which = FALSE) {
 	rings = getPolygonsPolygonsSlot(Polygons)
-	res = lapply(rings, function(x, pts) pointsInPolygon(pts, x), pts = pts)
-	if (which) {
-		ret = rep(as.numeric(NA), nrow(coordinates(pts)))
-		for (i in seq(along = res))
-			ret[res[[i]] > 0] = i
-		
-	} else {
-		ret = rep(FALSE, nrow(coordinates(pts)))
-		for (i in seq(along = res))
-			ret = ret | (res[[i]] > 0)
+	res = matrix(unlist(lapply(rings, function(x, pts) 
+		pointsInPolygon(pts, x), pts = pts)), ncol=length(rings))
+	res <- res > 0
+	holes <- sapply(rings, getPolygonHoleSlot)
+	if (any(holes)) {
+		holerows <- which(res[,holes], arr.ind=TRUE)[,1]
+		res[holerows,] <- FALSE
+		res[,holes] <- FALSE
 	}
+	ret <- apply(res, 1, any)
+	if (which) {
+		ret <- ifelse(ret, which(apply(res, 2, any)), as.integer(NA))
+	} 	
 	ret
 }
 
-pointsInSpatialPolygons = function(pts, SpRings) {
-	sr = getSpPpolygonsSlot(SpRings)
+pointsInSpatialPolygons = function(pts, SpPolygons) {
+	sr = getSpPpolygonsSlot(SpPolygons)
 	res = lapply(sr, function(x, pts) pointsInPolygons(pts, x), pts = pts)
 	ret = rep(as.numeric(NA), nrow(coordinates(pts)))
 	for (i in seq(along = res))
